@@ -13,8 +13,8 @@
 # limitations under the License.
 
 """
-MLflow
-------
+MLflow Logger
+-------------
 """
 import re
 import warnings
@@ -39,7 +39,9 @@ LOCAL_FILE_URI_PREFIX = "file:"
 
 class MLFlowLogger(LightningLoggerBase):
     """
-    Log using `MLflow <https://mlflow.org>`_. Install it with pip:
+    Log using `MLflow <https://mlflow.org>`_.
+
+    Install it with pip:
 
     .. code-block:: bash
 
