@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import torch
-from typing import Any, Optional
+from typing import Any, Callable, Optional
 
 from pytorch_lightning.metrics.metric import Metric
 from pytorch_lightning.metrics.functional.mean_squared_error import (
@@ -50,11 +50,13 @@ class MeanSquaredError(Metric):
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
         process_group: Optional[Any] = None,
+        dist_sync_fn: Callable = None,
     ):
         super().__init__(
             compute_on_step=compute_on_step,
             dist_sync_on_step=dist_sync_on_step,
             process_group=process_group,
+            dist_sync_fn=dist_sync_fn,
         )
 
         self.add_state("sum_squared_error", default=torch.tensor(0.0), dist_reduce_fx="sum")
