@@ -73,7 +73,7 @@ def find_free_network_port() -> int:
     return port
 
 
-def gather_all_tensors_if_available(result: Union[torch.Tensor], group: Optional[Any] = None):
+def gather_all_tensors(result: Union[torch.Tensor], group: Optional[Any] = None):
     """
     Function to gather all tensors from several ddp processes onto a list that
     is broadcasted to all processes
@@ -85,26 +85,41 @@ def gather_all_tensors_if_available(result: Union[torch.Tensor], group: Optional
     Return:
         gathered_result: list with size equal to the process group where
             gathered_result[i] corresponds to result tensor from process i
-
     """
-    if torch.distributed.is_available() and torch.distributed.is_initialized():
-        if group is None:
-            group = torch.distributed.group.WORLD
+    if group is None:
+        group = torch.distributed.group.WORLD
 
-        world_size = torch.distributed.get_world_size(group)
+    world_size = torch.distributed.get_world_size(group)
 
-        gathered_result = [torch.zeros_like(result) for _ in range(world_size)]
+    gathered_result = [torch.zeros_like(result) for _ in range(world_size)]
 
-        # sync and broadcast all
-        torch.distributed.barrier(group=group)
-        torch.distributed.all_gather(gathered_result, result, group)
+    # sync and broadcast all
+    torch.distributed.barrier(group=group)
+    torch.distributed.all_gather(gathered_result, result, group)
 
-        result = gathered_result
-    return result
+    return gathered_result
 
 
 def sync_ddp_if_available(
     result: Union[torch.Tensor], group: Optional[Any] = None, reduce_op: Optional[Union[ReduceOp, str]] = None
+) -> torch.Tensor:
+    """
+    Function to reduce a tensor across worker processes during distributed training
+    Args:
+        result: the value to sync and reduce (typically tensor or number)
+        group: the process group to gather results from. Defaults to all processes (world)
+        reduce_op: the reduction operation. Defaults to sum.
+            Can also be a string of 'avg', 'mean' to calculate the mean during reduction.
+    Return:
+        reduced value
+    """
+    if torch.distributed.is_available() and torch.distributed.is_initialized():
+        return sync_ddp(result, group=group, reduce_op=reduce_op)
+    return result
+
+
+def sync_ddp(
+    result: Union[torch.Tensor], group: Optional[Any] = None, reduce_op: Optional[Union[ReduceOp, str]] = None
 ) -> torch.Tensor:
     """
     Function to reduce the tensors from several ddp processes to one master process
@@ -118,24 +133,22 @@ def sync_ddp_if_available(
     Return:
         reduced value
     """
+    divide_by_world_size = False
 
-    if torch.distributed.is_available() and torch.distributed.is_initialized():
-        divide_by_world_size = False
+    if group is None:
+        group = torch.distributed.group.WORLD
 
-        if group is None:
-            group = torch.distributed.group.WORLD
+    if reduce_op is None:
+        reduce_op = torch.distributed.ReduceOp.SUM
+    elif isinstance(reduce_op, str) and reduce_op in ("avg", "mean"):
+        reduce_op = torch.distributed.ReduceOp.SUM
+        divide_by_world_size = True
 
-        if reduce_op is None:
-            reduce_op = torch.distributed.ReduceOp.SUM
-        elif isinstance(reduce_op, str) and reduce_op in ("avg", "mean"):
-            reduce_op = torch.distributed.ReduceOp.SUM
-            divide_by_world_size = True
+    # sync all processes before reduction
+    torch.distributed.barrier(group=group)
+    torch.distributed.all_reduce(result, op=reduce_op, group=group, async_op=False)
 
-        # sync all processes before reduction
-        torch.distributed.barrier(group=group)
-        torch.distributed.all_reduce(result, op=reduce_op, group=group, async_op=False)
-
-        if divide_by_world_size:
-            result = result / torch.distributed.get_world_size(group)
+    if divide_by_world_size:
+        result = result / torch.distributed.get_world_size(group)
 
     return result
